{ config, lib, ... }:

let
  sources = import ./../../../shared/sources;

  flake-compat = sources.flake-compat;
  drtvrss = import flake-compat { src = sources.drtvrss; };

  svc_domain = "drtv.${config.mine.shared.settings.domain}";

  port = 8125;
in {
  imports = [
    # (builtins.trace drtvrss.defaultNix.nixosModules.x86_64-linux.default drtvrss.defaultNix.nixosModules.default) 
    drtvrss.defaultNix.nixosModules.x86_64-linux.default 
  ];

  services.drtvrss = {
    enable = true;
    host = "127.0.0.1:${builtins.toString port}";
    base_url = "https://${svc_domain}";
    klagemail = "rasmus@rend.al";
    recommended_shows = [ "matador_130149" ];
  };

  systemd.services.drtvrss.confinement.enable = lib.mkForce false;

  # nginx
  services.nginx.virtualHosts."${svc_domain}" = {
    forceSSL = true;
    enableACME = true;
    
    locations."/".proxyPass = "http://localhost:${builtins.toString port}";
  };

  # meta
  mine.shared.meta.drtvrss = rec {
    name = "DRTV RSS";
    description = ''
      Alternative frontend for DRTV, whithout the requirement to login + the ability to generate RSS feeds of your favorite shows.
    '';
    url = "https://${svc_domain}";

    package = {
      name = "drtvrss";
      version = "v0.0.1";
      meta = with lib; {
        description = "DRTVRSS";
        license = licenses.agpl3Only;
        homepage = "https://github.com/RasmusRendal/drtvrss";
        platforms = platforms.all;
      };
    };
  };
}
